# RejectPaymentRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**gateway_reconciliation_reason** | **str** | The reason of gateway reconciliation.  | [optional] 
**gateway_reconciliation_status** | **str** | The status of gateway reconciliation.  | [optional] 
**gateway_response** | **str** | The transaction response returned by the gateway for this transaction. If the transaction was declined, this reason is provided in the message. | [optional] 
**gateway_response_code** | **str** | Response message Code returned by the gateway about the transaction status. | [optional] 
**reference_id** | **str** | Unique Id generated by the gateway for each transaction. Use this ID to find the respective Zuora Payment ID.  | [optional] 
**second_reference_id** | **str** | The second reference Id. Some gateway uses two unique transaction IDs.  | [optional] 
**settled_on** | **str** | The date and time of the transaction settlement. The format is &#x60;yyyy-mm-dd hh:mm:ss&#x60;. | [optional] 

## Example

```python
from zuora_sdk.models.reject_payment_request import RejectPaymentRequest

# TODO update the JSON string below
json = "{}"
# create an instance of RejectPaymentRequest from a JSON string
reject_payment_request_instance = RejectPaymentRequest.from_json(json)
# print the JSON string representation of the object
print(RejectPaymentRequest.to_json())

# convert the object into a dict
reject_payment_request_dict = reject_payment_request_instance.to_dict()
# create an instance of RejectPaymentRequest from a dict
reject_payment_request_from_dict = RejectPaymentRequest.from_dict(reject_payment_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


